summaryrefslogtreecommitdiffstats
path: root/kpresenter/KPrRotationDialogImpl.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/KPrRotationDialogImpl.h')
-rw-r--r--kpresenter/KPrRotationDialogImpl.h31
1 files changed, 17 insertions, 14 deletions
diff --git a/kpresenter/KPrRotationDialogImpl.h b/kpresenter/KPrRotationDialogImpl.h
index 2eb2586b..7741ff76 100644
--- a/kpresenter/KPrRotationDialogImpl.h
+++ b/kpresenter/KPrRotationDialogImpl.h
@@ -19,13 +19,13 @@
#ifndef __rotationdialogimpl_h__
#define __rotationdialogimpl_h__
-#include <qlabel.h>
+#include <tqlabel.h>
#include <kdialogbase.h>
class KPrTextPreview;
class RotationPropertyUI;
-class QObject;
-class QEvent;
+class TQObject;
+class TQEvent;
class KPrCircleGroup;
/**
@@ -34,9 +34,10 @@ class KPrCircleGroup;
class KPrRotationDialogImpl : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- KPrRotationDialogImpl( QWidget *parent, const char* name = 0 );
+ KPrRotationDialogImpl( TQWidget *tqparent, const char* name = 0 );
~KPrRotationDialogImpl() {}
void setAngle( double angle );
@@ -60,18 +61,19 @@ private:
* A toggle-button like widget that shows one pixmap when it is checked,
* and another when it is unselected.
*/
-class KPrCircleToggle : public QLabel
+class KPrCircleToggle : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent the parent widget, as required by Qt.
* @param image the named image that we will use. "rotate/" is
* prepended and "dn" is appended for the checked state.
* @param id the id that will be used in the clicked signal
*/
- KPrCircleToggle(QWidget *parent, const QString &image, int id);
+ KPrCircleToggle(TQWidget *tqparent, const TQString &image, int id);
/// return the id which is passed in the constructor
int id() { return m_id; }
@@ -87,11 +89,11 @@ public slots:
void setChecked(bool on);
protected:
- /// overwritten method from QWidget.
- void mousePressEvent ( QMouseEvent * e );
+ /// overwritten method from TQWidget.
+ void mousePressEvent ( TQMouseEvent * e );
private:
- QPixmap m_on, m_off;
+ TQPixmap m_on, m_off;
bool m_selected;
int m_id;
};
@@ -99,15 +101,16 @@ private:
/**
* A button-group equivalent for a set of KPrCircleToggle classes.
*/
-class KPrCircleGroup : public QFrame
+class KPrCircleGroup : public TQFrame
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor.
* @param parent the parent widget, as required by Qt.
*/
- KPrCircleGroup(QWidget *parent);
+ KPrCircleGroup(TQWidget *tqparent);
/**
* Set the angle the group is currently representing. If there is a child button
* that registred itself (using add()) with an ID that matches the argument angle
@@ -129,7 +132,7 @@ private slots:
void selectionChanged(int buttonId);
private:
- QPtrList<KPrCircleToggle> m_buttons;
+ TQPtrList<KPrCircleToggle> m_buttons;
bool noSignals;
};
@@ -60,18 +61,19 @@ private:
/**
* Constructor.
- * @param parent the parent widget, as required by Qt.
+ * @param tqparent the tqparent widget, as required by TQt.
* @param image the named image that we will use. "rotate/" is
* prepended and "dn" is appended for the checked state.
@@ -99,15 +101,16 @@ private:
/**
* Constructor.
- * @param parent the parent widget, as required by Qt.
+ * @param tqparent the tqparent widget, as required by TQt.
*/